@@ -138,7 +138,8 @@ def getProfileClass(
         user_ttl=None,
         user_data_ttl_margin=None,
         clean_queue_ttl=None,
-        new_user_detection_ttl=None):
+        new_user_detection_ttl=None,
+        max_stitch_keys=None):
 
     cls = Profile
     cls.domain = domain
@@ -158,6 +159,7 @@ def getProfileClass(
     cls.user_ttl = user_ttl
     cls.user_data_ttl_margin = user_data_ttl_margin
     cls.clean_queue_ttl = clean_queue_ttl
+    cls.max_stitch_keys = max_stitch_keys
 
     return cls
 
@@ -167,7 +169,8 @@ def getStitchClass(
         django_stitch_model,
         django_connection_tuple,
         user_ttl=None,
-        user_data_ttl_margin=None):
+        user_data_ttl_margin=None,
+        max_stitch_keys=None):
 
     cls = Stitch
     cls.domain = domain
@@ -176,6 +179,7 @@ def getStitchClass(
     cls.django_connection_tuple = django_connection_tuple
     cls.user_ttl = user_ttl
     cls.user_data_ttl_margin = user_data_ttl_margin
+    cls.max_stitch_keys = max_stitch_keys
 
     return cls
 
