@@ -76,6 +76,7 @@ class LuaScripts(object):
         ARGV[4]: user id (ARGV[6])
         ARGV[5]: array with pointers (can be empty) (ARGV[7])
         ARGV[6]: array with stitch keys (can be empty)
+        ARGV[7]: max lenghth stitch objects (pool & stitch itself)
         '''
         return '''
             local new_user = (redis.call('EXISTS', KEYS[1]) == 0)
@@ -130,10 +131,23 @@ class LuaScripts(object):
 
             -- add stitch keys
             local stitch_keys = cjson.decode(ARGV[6])
-            for idx, el in pairs(stitch_keys) do
-                redis.call('ZADD', el, timestamp_now, ARGV[4])
-                redis.call('EXPIRE', el, {user_ttl_with_margin})
-                redis.call('ZADD', KEYS[7], timestamp_now, el)
+            if #stitch_keys > 0 then
+                local max_len_stitch_objects = tonumber(ARGV[7])
+                for idx, el in pairs(stitch_keys) do
+                    redis.call('ZADD', el, timestamp_now, ARGV[4])
+                    local len_stitch = redis.call('ZCARD', el)
+                    if len_stitch > max_len_stitch_objects then
+                        redis.call('ZREMRANGEBYRANK', el, 0, len_stitch - max_len_stitch_objects - 1) 
+                    end
+                    redis.call('EXPIRE', el, {user_ttl_with_margin})
+                    redis.call('ZADD', KEYS[7], timestamp_now, el)
+                end
+                if #stitch_keys > 0 then
+                    local len_stitch_pool = redis.call('ZCARD', KEYS[7])                    
+                    if len_stitch_pool > max_len_stitch_objects then
+                        redis.call('ZREMRANGEBYRANK', KEYS[7], 0, len_stitch_pool - max_len_stitch_objects - 1)                    
+                    end
+                end
                 redis.call('EXPIRE', KEYS[7], {user_ttl_with_margin})
             end
 
