@@ -24,6 +24,7 @@ DEFAULT_USER_TTL = 6 * 24 * 60 * 60
 DEFAULT_USER_DATA_TTL_MARGIN = 2
 DEFAULT_FAST_CLEAN_THRESHOLD = 3
 DEFAULT_CLEAN_QUEUE_TTL = 24 * 60 * 60
+DEFAULT_MAX_STITCH_KEYS = 50
 
 def set_data_type_properties(cls):
 
@@ -57,6 +58,7 @@ class Profile(object):
     user_ttl = DEFAULT_USER_TTL
     user_data_ttl_margin = DEFAULT_USER_DATA_TTL_MARGIN
     clean_queue_ttl = DEFAULT_CLEAN_QUEUE_TTL
+    max_stitch_keys = DEFAULT_MAX_STITCH_KEYS
 
     def __init__(self,
                  key=None,
@@ -630,7 +632,8 @@ class Profile(object):
                 str(self.session_id or 'none'),
                 str(self.user_id),
                 json.dumps(self.create_pointers(pointers)),
-                json.dumps(self.create_stitch_keys(stitch_keys))
+                json.dumps(self.create_stitch_keys(stitch_keys)),
+                self.max_stitch_keys
             ]
         )
         return bool(int(new_user_detected.decode()))
