@@ -9,6 +9,7 @@ DEFAULT_DJANGO_STITCH_MODEL = None
 DEFAULT_DJANGO_CONNECTION_TUPLE = (None, None)
 DEFAULT_USER_TTL = 6 * 24 * 60 * 60
 DEFAULT_USER_DATA_TTL_MARGIN = 2
+DEFAULT_MAX_STITCH_KEYS = 50
 
 class StitchPool(object):
 
@@ -110,6 +111,7 @@ class Stitch(object):
     user_data_ttl_margin = DEFAULT_USER_DATA_TTL_MARGIN
     django_stitch_model = DEFAULT_DJANGO_STITCH_MODEL
     django_connection_tuple = DEFAULT_DJANGO_CONNECTION_TUPLE
+    max_stitch_keys = DEFAULT_MAX_STITCH_KEYS
 
     def __init__(self,
                  value,
